@@ -318,15 +318,19 @@ DOCX_TABLE_CELL = docx_qn('tc')
 
 
 def gen_xml_files_from_docx(fp: BinaryIO) -> Iterator[str]:
-    z = zipfile.ZipFile(fp)
-    filelist = z.namelist()
-    for filename in filelist:
-        if DOCX_HEADER_FILE_REGEX.match(filename):
-            yield z.read(filename).decode("utf8")
-    yield z.read(DOCX_DOC_FILE)
-    for filename in filelist:
-        if DOCX_FOOTER_FILE_REGEX.match(filename):
-            yield z.read(filename).decode("utf8")
+    try:
+        z = zipfile.ZipFile(fp)
+        filelist = z.namelist()
+        for filename in filelist:
+            if DOCX_HEADER_FILE_REGEX.match(filename):
+                yield z.read(filename).decode("utf8")
+        yield z.read(DOCX_DOC_FILE)
+        for filename in filelist:
+            if DOCX_FOOTER_FILE_REGEX.match(filename):
+                yield z.read(filename).decode("utf8")
+    except zipfile.BadZipFile:
+        # Clarify the error:
+        raise zipfile.BadZipFile("File is not a zip file - encrypted DOCX?")
 
 
 def docx_text_from_xml(xml: str, **kwargs) -> str:
